@@ -110,8 +110,8 @@ class Object():
                 raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{name}'")
         elif name in self.__dict__:
             return self.__dict__[name]
-        elif name in dir(self)
-            return getattr(self, name)
+        elif name in dir(self):
+            return getattr(self.__class__, name)
         else:
             raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{name}'")
 
